******************************************
## Welcome to `ibm-watson-machine-learning`
******************************************

``ibm-watson-machine-learning`` is a library that allows to work with Watson Machine Learning service on [IBM Cloud](https://console.bluemix.net/catalog/services/machine-learning) and
IBM Cloud for Data. Train, test and deploy your models as APIs for application development, share with colleagues using this python library.

### [Package Sphinx documentation](http://ibm-wml-api-pyclient.mybluemix.net)
==========================================
